import { Col } from "zol";


/**
 * PostgreSQL `JSON` or `JSONB` type
 */
export declare class PGJson {
    static parser(val: string): PGJson;
    static col<s>(json: any): Col<s, PGJson>;
    /**
     * Get JSON array element (indexed from zero, negative integers count from the end)
     *
     * This is the PostgreSQL `->` operator
     */
    static arrayElem<s>(lhs: Col<s, PGJson>, rhs: Col<s, number>): Col<s, PGJson | null>;
    /**
     * Get JSON object field by key
     *
     * This is the PostgreSQL `->` operator
     */
    static objField<s>(lhs: Col<s, PGJson>, rhs: Col<s, string>): Col<s, PGJson | null>;
    /**
     * Get JSON array element as text (indexed from zero, negative integers count from the end)
     *
     * This is the PostgreSQL `->>` operator
     */
    static arrayElemAsText<s>(lhs: Col<s, PGJson>, rhs: Col<s, number>): Col<s, string | null>;
    /**
     * Get JSON object field as text
     *
     * This is the PostgreSQL `->>` operator
     */
    static objFieldAsText<s>(lhs: Col<s, PGJson>, rhs: Col<s, string>): Col<s, string | null>;
    static buildObject<s>(values: PGJson.Build<s>[]): Col<s, PGJson>;
    /**
     * The actual JSON object
     */
    readonly data: any;
    protected dummy: PGJson;
}

export declare namespace PGJson {
    interface Build<s> {
        key: Col<s, string>;
        value: Col<s, any>;
    }
}


