import { SqlType, Unsafe, textCol } from 'zol';

/**
 * PostgreSQL `JSON` or `JSONB` type
 */
var PGJson = (function () {
    function PGJson() {
    }
    PGJson.parser = function (val) {
        return {
            data: JSON.parse(val)
        };
    };
    PGJson.col = function (json) {
        return Unsafe.unsafeCast(textCol(JSON.stringify(json)), "JSONB", PGJson.parser);
    };
    /**
     * Get JSON array element (indexed from zero, negative integers count from the end)
     *
     * This is the PostgreSQL `->` operator
     */
    PGJson.arrayElem = function (lhs, rhs) {
        return Unsafe.unsafeBinOp("->", lhs, Unsafe.unsafeCast(rhs, "INT", SqlType.intParser), PGJson.parser);
    };
    /**
     * Get JSON object field by key
     *
     * This is the PostgreSQL `->` operator
     */
    PGJson.objField = function (lhs, rhs) {
        return Unsafe.unsafeBinOp("->", lhs, rhs, PGJson.parser);
    };
    /**
     * Get JSON array element as text (indexed from zero, negative integers count from the end)
     *
     * This is the PostgreSQL `->>` operator
     */
    PGJson.arrayElemAsText = function (lhs, rhs) {
        return Unsafe.unsafeBinOp("->>", lhs, Unsafe.unsafeCast(rhs, "INT", SqlType.intParser), SqlType.stringParser);
    };
    /**
     * Get JSON object field as text
     *
     * This is the PostgreSQL `->>` operator
     */
    PGJson.objFieldAsText = function (lhs, rhs) {
        return Unsafe.unsafeBinOp("->>", lhs, rhs, SqlType.stringParser);
    };
    PGJson.buildObject = function (values) {
        var args = [];
        for (var _i = 0, values_1 = values; _i < values_1.length; _i++) {
            var v = values_1[_i];
            args.push(v.key);
            args.push(v.value);
        }
        return Unsafe.unsafeFunN("jsonb_build_object", args, PGJson.parser);
    };
    return PGJson;
}());

export { PGJson };
//# sourceMappingURL=zol-json.es5.js.map
