(function (global, factory) {
	typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('zol')) :
	typeof define === 'function' && define.amd ? define(['exports', 'zol'], factory) :
	(factory((global.zolJson = {}),global.zol));
}(this, (function (exports,zol) { 'use strict';

/**
 * PostgreSQL `JSON` or `JSONB` type
 */
var PGJson = (function () {
    function PGJson() {
    }
    PGJson.parser = function (val) {
        return {
            data: JSON.parse(val)
        };
    };
    PGJson.col = function (json) {
        return zol.Unsafe.unsafeCast(zol.textCol(JSON.stringify(json)), "JSONB", PGJson.parser);
    };
    /**
     * Get JSON array element (indexed from zero, negative integers count from the end)
     *
     * This is the PostgreSQL `->` operator
     */
    PGJson.arrayElem = function (lhs, rhs) {
        return zol.Unsafe.unsafeBinOp("->", lhs, zol.Unsafe.unsafeCast(rhs, "INT", zol.SqlType.intParser), PGJson.parser);
    };
    /**
     * Get JSON object field by key
     *
     * This is the PostgreSQL `->` operator
     */
    PGJson.objField = function (lhs, rhs) {
        return zol.Unsafe.unsafeBinOp("->", lhs, rhs, PGJson.parser);
    };
    /**
     * Get JSON array element as text (indexed from zero, negative integers count from the end)
     *
     * This is the PostgreSQL `->>` operator
     */
    PGJson.arrayElemAsText = function (lhs, rhs) {
        return zol.Unsafe.unsafeBinOp("->>", lhs, zol.Unsafe.unsafeCast(rhs, "INT", zol.SqlType.intParser), zol.SqlType.stringParser);
    };
    /**
     * Get JSON object field as text
     *
     * This is the PostgreSQL `->>` operator
     */
    PGJson.objFieldAsText = function (lhs, rhs) {
        return zol.Unsafe.unsafeBinOp("->>", lhs, rhs, zol.SqlType.stringParser);
    };
    PGJson.buildObject = function (values) {
        var args = [];
        for (var _i = 0, values_1 = values; _i < values_1.length; _i++) {
            var v = values_1[_i];
            args.push(v.key);
            args.push(v.value);
        }
        return zol.Unsafe.unsafeFunN("jsonb_build_object", args, PGJson.parser);
    };
    return PGJson;
}());

exports.PGJson = PGJson;

Object.defineProperty(exports, '__esModule', { value: true });

})));
//# sourceMappingURL=zol-json.umd.js.map
